<?php
namespace Teknisa\CADCTB\Controllers;

use Teknisa\CADCTB\Services\Ger17700RendimentosSociosService;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Request\DataSet as RequestDataSet;
use Zeedhi\Framework\DataSource\DataSet;

class Ger17700RendimentosSociosController extends \Teknisa\CADCTB\Controllers\TeknisaCrud{

    protected $dataSourceName;
    protected $parameterBagColumns = array();
    protected $environment;
    protected $newCode;

    public function __construct($crudService, ParameterBag $parameterBag, Ger17700RendimentosSociosService $serviceRendimento) {
        $this->serviceRendimento = $serviceRendimento;
        $this->dataSourceName = "socio";
        parent::__construct($crudService, $parameterBag);
    }

    public function findSocios(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = "socio";
        parent::find($request, $response);
    }

    public function salvarSocio(DTO\Request $request, DTO\Response $response){
        $this->dataSourceName = "socio";
        try {
            $row = $request->getRow();
            if ($row['__is_new']) {
                $this->serviceRendimento->validateSocio($row);
                $nrSequencial = $this->serviceRendimento->generateSequentialCode('REGY600ECF');
                $row['NRSEQREG'] = $nrSequencial;

                $newDataSet = new DataSet($this->dataSourceName, array($row));
                $newRequest = new RequestDataSet($newDataSet, $request->getMethod(), $request->getRoutePath(), $request->getUserId());
                parent::save($newRequest, $response);
            } else {
                parent::save($request, $response);
            }
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function deleteSocio(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = "socio";
        $this->serviceRendimento->deleteSocioChildren($request->getRow()['NRSEQREG']);
        parent::delete($request, $response);
    }

    public function findSocioEmpresa(DTO\Request $request, DTO\Response $response){
        $this->dataSourceName = 'socio_quadro_societario';
        parent::find($request, $response);
    }

    public function salvarQuadroSocietario(DTO\Request $request, DTO\Response $response){
        $this->dataSourceName = "socio_quadro_societario";
        try {
            $row = $request->getRow();
            if ($row['__is_new'] === true) {
                $this->serviceRendimento->validateRelacao($row);
                $nrSequencial = $this->serviceRendimento->generateSequentialCode('SOCIOEMPRESA');
                $row['NRSEQSOCEMPR'] = $nrSequencial;
                
                $newDataSet = new DataSet($this->dataSourceName, array($row));
                $newRequest = new RequestDataSet($newDataSet, $request->getMethod(), $request->getRoutePath(), $request->getUserId());
                parent::save($newRequest, $response);
            } else {
                parent::save($request, $response);
            }
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function deleteQuadroSocietario(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = 'socio_quadro_societario';
        parent::delete($request, $response);
    }

    public function findRendimentoSocio(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = 'socio_rendimento';
        parent::find($request, $response);
    }

    public function saveRendimentoSocio(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = 'socio_rendimento';
        try {
            $row = $request->getRow();
            $this->serviceRendimento->validateRendimento($row);
            if ($row['__is_new'] === true) {
                $nrSequencial = $this->serviceRendimento->generateSequentialCode('REGY611ECF');
                $row['NRSEQREGY611'] = $nrSequencial;

                $newDataSet = new DataSet($this->dataSourceName, array($row));
                $newRequest = new RequestDataSet($newDataSet, $request->getMethod(), $request->getRoutePath(), $request->getUserId());
                parent::save($newRequest, $response);
            } else {
                parent::save($request, $response);
            }
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function deleteRendimentoSocio(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = 'socio_rendimento';
        parent::delete($request, $response);
    }

}